/* REXX script                                                             */
/*                                                                         */
/* $Id: install.cmd,v 1.2 1999/03/17 14:34:37 gloverjs Exp $                                                                    */
/*                                                                         */
/* This software was produced by Sigsworth Engineering Services.           */
/* All Rights Reserved, Copyright(C) 1999, Sigsworth Engineering Services. */
/*                                                                         */
/* Project name: random                                                    */
/*                                                                         */
/* Project/Contract Number:  8                                             */
/* #A John S Glover                                                        */
/*                                                                         */
/*    Description                                                          */
/*    -----------                                                          */
/* #D Installs the random DLL onto an OS/2 system                          */

VERSION = 1.0;

SUCCESS = 0;
FAILURE = -1;

TRUE = 1;
FALSE = 0;

/* load all system REXX functions */
call RxFuncAdd 'SysLoadFuncs', 'rexxUtil', 'SysLoadFuncs'
call SysLoadFuncs

say 'Installation utility for random.dll'
say 'All Rights Reserved, Copyright(C) 1999, Sigsworth Engineering Services.'
say

say 'Checking all files available to install ...'
filesToInstall = readme.txt random.dll random.def random.lib random.h random.inf;

FileExists = TRUE;
do while filesToInstall > ""
  parse var filesToInstall this_file filesToInstall;

  /* verify file exists */
  if stream(this_file, 'c', 'query exists') = '' then do
    say "ERROR:" this_file "does not exists";
    FileExists = FALSE;
  end
  else do
    say this_file "exists. OK.";
  end
end; /* do */

if  FileExists = TRUE then do
  say '... all present.';
end
else do
  say "... some files are missing. Exiting.";
  exit FAILURE;
end  /* if */
say

/* determine drive & directory on which to move files */

/* find out all available drives & select valid one */
drivesMap = SysDriveMap(,);            /* default are start at C & all drives */
say "Available drives are:" drivesMap;

/* ask for installation drive &                     */
/* loop around until user enters drive which exists */
validDrive = 1;
do while validDrive = 1
  installDrive = "C:";
  say "Install files to drive ...";
  pull enteredDrive;

  validDrive = TestDriveExists(enteredDrive, drivesMap);
end; /* do */

/* ask for installation directory                       */
/* loop around until user enters directory which exists */
/* or can be created                                    */
say "Install files to directory ...";
pull enteredDirectory;

/* test if dir exists */
fullPath = enteredDrive||enteredDirectory;

rc = TestDirExists(fullPath);

if rc = \0 then do
  say fullPath||" does not exist.";

  validResponse = FALSE
  do while validResponse = FALSE
    say "Shall I create the path? [y/n]";
    pull userReply;
    if userReply = "Y" | userReply = "N" then do
      validResponse = TRUE;
    end /* do */
    else do
      say "Invalid response. Y, y, N or n please";
    end /* do */
  end /* do */
end
else do
  say "Programs to be installed in "||fullPath;
end  /* if */


if userReply = "Y" then do
  rc = SysMkDir(fullPath);
  if rc = \0  then do
    say "ERROR: failed to create "||fullPath;
    exit;
  end /* do */
end /* do */

say
say "The following sub-directories will be created";
say "if they do not exist.";
say fullPath||"\dll :- location for the dynamic link library.";
say fullPath||"\include :- location for the include file.";
say fullPath||"\hlp :- location for the help file documentation.";

/* test for existence of dll directory & create if doesn't exist */
rc = TestDirExists(fullPath||"\dll");
if rc = \0 then do
  say "Creating "||fullPath||"\dll";
  rc = SysMkDir(fullPath||"\dll");
  if rc = \0 then do
    say "ERROR: failed to create "||fullPath||"\dll";
  end /* do */
end /* do */

/* test for existence of hlp directory & create if doesn't exist */
rc = TestDirExists(fullPath||"\hlp");
if rc = \0 then do
  say "Creating "||fullPath||"\hlp";
  rc = SysMkDir(fullPath||"\hlp");
  if rc = \0 then do
    say "ERROR: failed to create "||fullPath||"\hlp";
  end /* do */
end /* do */

/* test for existence of include directory & create if doesn't exist */
rc = TestDirExists(fullPath||"\include");
if rc = \0 then do
  say "Creating "||fullPath||"\include";
  rc = SysMkDir(fullPath||"\include");
  if rc = \0 then do
    say "ERROR: failed to create "||fullPath||"\include";
  end /* do */
end /* do */

/* transcribe files to appropriate locations */
/* install dll */
currentDir = directory();
fromPoint = currentDir||"\random.dll";
destPoint = fullPath||"\dll\random.dll";
'@copy ' fromPoint destPoint '1>NUL 2>NUL'
if rc = \0 then do
  say "ERROR: failed to install random.dll to "||fullPath||"\dll\random.dll";
end /* do */

/* install def */
currentDir = directory();
fromPoint = currentDir||"\random.def";
destPoint = fullPath||"\dll\random.def";
'@copy ' fromPoint destPoint ' 1>NUL 2>NUL'
if rc = \0 then do
  say "ERROR: failed to install random.def"||fullPath||"\dll\random.def";
end /* do */

/* install lib */
currentDir = directory();
fromPoint = currentDir||"\random.lib";
destPoint = fullDir||"\dll\random.lib";
'@copy ' fromPoint destPoint ' 1>NUL 2>NUL'
if rc = \0 then do
  say "ERROR: failed to install random.lib"||fullPath||"\dll\random.lib";
end /* do */

/* install include */
currentDir = directory();
fromPoint = currentDir||"\random.h";
destPoint = fullPath||"\include\random.h";
'@copy ' fromPoint destPoint '1>NUL 2>NUL'
if rc = \0 then do
  say "ERROR: failed to install random.h to "||fullPath||"\include\random.h";
end /* do */

/* install inf */
currentDir = directory();
fromPoint = currentDir||"\random.inf";
destPoint = fullPath||"\hlp\random.inf";
'@copy ' fromPoint destPoint '1>NUL 2>NUL'
if rc = \0 then do
  say "ERROR: failed to install random.inf to "||fullPath||"\hlp\random.inf";
end /* do */

say
say "In order for random.dll to be located add the dll path to LIBPATH in";
say "your config.sys file.";
say "WARNING: Take care editing config.sys not to break your system's";
say "         configuration. Make a backup copy.";
say "Don't forget to include the random.h file in your new C++ programs when";
say "using this dll in your code.";
say
say 'Finished'
say

exit SUCCESS;
/* end main routine */

/* #F TestDirExists()                                       */
/*                                                          */
/* #D Test if specified directory exists on specified drive */
/* #D Return 0 if exists else 1                             */
TestDirExists:
  procedure;

  arg testDir;

  /* get current directory so know where came from */
  currentDir = directory();
  
  /* try to change to testDir                                           */
  /* if unsuccessful testDir does not exist & dirExists is empty string */
  /* set return value to 1                                              */
  /* else does exist therefore set return value to 0 & revert to curdir */
  dirExists = directory(testDir);
  if dirExists = "" then
  do
    returnVal = 1;
  end;
  else
  do
    returnVal = 0;
    dummy = directory(currentDir);
  end;  /* if */
return returnVal; /* TestDirExists() */

/* #F TestDriveExists()             */
/*                                  */
/* #D Testif specified drive exists */
/* #D Return 0 if exists esle 1     */
TestDriveExists:
  procedure;

  arg enteredDrive, drivesMap;

  returnVal = 1;

  /* test users entered selection against all valid possibilities */
  workingDrivesMap = drivesMap;
  do while workingDrivesMap > ""
    parse var workingDrivesMap thisDrive workingDrivesMap;

    /* verify drive exists */
    if enteredDrive = thisDrive then do
      returnVal = 0;
    end
  end; /* do */
 
return returnVal; /* TestDriveExists() */

/* #F PrintHelpMsg()                    */
/*                                      */
/* #D Display a help message to stdout. */
PrintHelpMsg:
  say "usage: setccode [/h /v] <Input file>";
  say "       [/h -h /? -?]: Display this help message.";
  say "       [/v -v]: Display version information.";
  say "";
  say "setccode sets the TYPE extended attribute of input file to C Code.";
  say
  exit SUCCESS;
return;
/* PrintHelpMsg() */

/* end install.cmd */
